<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_opensearch;

use Drupal\Core\Logger\LoggerChannelInterface;
use OpenSearch\Client;
use OpenSearch\GuzzleClientFactory;

/**
 * A class that represents the factory for an OpenSearch client.
 *
 * @package Drupal\data_pipelines_opensearch\Factory
 */
class ClientFactory implements ClientFactoryInterface {

  /**
   * The constructor for ClientFactory.
   *
   * @param \Drupal\Core\Logger\LoggerChannelInterface $loggerChannel
   *   The logger channel.
   */
  public function __construct(protected LoggerChannelInterface $loggerChannel) {}

  /**
   * The instantiated OpenSearch client.
   *
   * @var \OpenSearch\Client|null
   */
  protected ?Client $client = NULL;

  /**
   * {@inheritdoc}
   */
  public function create(string $url, string $username, string $password): ?Client {
    if (!$this->client) {
      try {
        $this->client = (new GuzzleClientFactory())->create([
          'base_uri' => $url,
          'auth' => [
            $username,
            $password,
          ],
        ]);
      }
      catch (\Exception $e) {
        $this->loggerChannel->error($e->getMessage());
      }
    }
    return $this->client;
  }

}
