<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_opensearch;

/**
 * A class that represents a documents request proxy.
 *
 * @package Drupal\data_pipelines_opensearch\Request
 */
class DocumentsRequest extends Request implements DocumentsRequestInterface {

  /**
   * {@inheritdoc}
   */
  public function create(Index $index, array $documents): array {
    $params = [];
    $params['index'] = $index->getId();
    $params['body'] = [];
    foreach ($documents as $document) {
      $params['body'][] = [
        'index' => [
          '_index' => $index->getId(),
          '_id' => $document->getId(),
        ],
      ];
      $params['body'][] = $document->getData();
    }
    return $this->client->bulk($params);
  }

  /**
   * {@inheritdoc}
   */
  public function delete(Index $index, array $documents): array {
    $params = [];
    $params['index'] = $index->getId();
    $params['body'] = [];
    foreach ($documents as $document) {
      $params['body'][] = [
        'delete' => [
          '_index' => $index->getId(),
          '_id' => $document->getId(),
        ],
      ];
    }
    return $this->client->bulk($params);
  }

  /**
   * {@inheritdoc}
   */
  public function last(Index $index):? Document {
    $params = [];
    $params['index'] = $index->getId();
    $params['body'] = [
      'size' => 1,
      'sort' => [
        '@delta' => [
          'order' => 'desc',
        ],
      ],
    ];
    $response = $this->client->search($params);
    if (!empty($response['hits']['hits'])) {
      $hit = $response['hits']['hits'][0];
      return new Document($hit['_id'], $index, $hit['_source'], $hit['_source']['@delta']);
    }
    return NULL;
  }

}
