<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_opensearch;

/**
 * An interface for the adjacent class.
 *
 * @package Drupal\data_pipelines_opensearch\Request
 */
interface DocumentsRequestInterface {

  /**
   * A method that bulk creates documents by way of the OpenSearch client.
   *
   * @param \Drupal\data_pipelines_opensearch\Index $index
   *   The index.
   * @param \Drupal\data_pipelines_opensearch\Document[] $documents
   *   The document.
   *
   * @return array
   *   The response.
   */
  public function create(Index $index, array $documents): array;

  /**
   * A method that bulk deletes documents by way of the OpenSearch client.
   *
   * @param \Drupal\data_pipelines_opensearch\Index $index
   *   The index.
   * @param \Drupal\data_pipelines_opensearch\Document[] $documents
   *   The documents.
   *
   * @return array
   *   The response.
   */
  public function delete(Index $index, array $documents): array;

  /**
   * A method to get the last document by way of the OpenSearch client.
   *
   * @param \Drupal\data_pipelines_opensearch\Index $index
   *   The index.
   *
   * @return \Drupal\data_pipelines_opensearch\Document|null
   *   The document or null.
   */
  public function last(Index $index):? Document;

}
