<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_opensearch;

/**
 * A class that represents a index object.
 *
 * Used as a value object for index requests.
 *
 * @package Drupal\data_pipelines_opensearch\Request\Object
 */
class Index {

  /**
   * The constructor for Index.
   *
   * @param string $id
   *   The index ID.
   * @param array $settings
   *   The index settings.
   */
  public function __construct(protected string $id, protected array $settings = []) {}

  /**
   * A method to get the index ID.
   *
   * @return string
   *   The index ID.
   */
  public function getId(): string {
    return $this->id;
  }

  /**
   * A method to set the index ID.
   *
   * @param string $id
   *   The index ID.
   *
   * @return $this
   *   The index.
   */
  public function setId(string $id): self {
    $this->id = $id;
    return $this;
  }

  /**
   * A method to set the index settings.
   *
   * @param array $settings
   *   The index settings.
   *
   * @return $this
   *   The index.
   */
  public function setSettings(array $settings): self {
    $this->settings = $settings;
    return $this;
  }

  /**
   * A method to get the index settings.
   *
   * @return array
   *   The index settings.
   */
  public function getSettings(): array {
    return $this->settings;
  }

}
