<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_opensearch;

/**
 * An interface for the adjacent class.
 *
 * @package Drupal\data_pipelines_opensearch\Request
 */
interface IndexRequestInterface {

  /**
   * A method that creates an index by way of the OpenSearch client.
   *
   * @param Index $index
   *   The index.
   *
   * @return array
   *   The response.
   */
  public function create(Index $index): array;

  /**
   * A method that deletes an index by way of the OpenSearch client.
   *
   * @param Index $index
   *   The index.
   *
   * @return array
   *   The response.
   */
  public function delete(Index $index): array;

  /**
   * A method checks the existence of an index by way of the OpenSearch client.
   *
   * @param Index $index
   *   The index.
   *
   * @return bool
   *   The result.
   */
  public function exists(Index $index): bool;

}
