<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines_opensearch\Kernel;

use Drupal\Tests\data_pipelines\Kernel\DatasetKernelTestBase;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Entity\Destination;
use Drupal\data_pipelines\Entity\DestinationInterface;

/**
 * A class that acts as a base for kernel tests.
 *
 * @package Drupal\Tests\data_pipelines_opensearch\Kernel
 */
abstract class OpenSearchTestBase extends DatasetKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'data_pipelines_opensearch',
    'data_pipelines_opensearch_test',
  ];

  /**
   * A method to create a test OpenSearch destination.
   *
   * @param array $values
   *   The destination values.
   *
   * @return \Drupal\data_pipelines\Entity\DestinationInterface
   *   The destination entity.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createTestOpenSearchDestination(array $values = []): DestinationInterface {
    $id = $values['id'] ?? $this->randomMachineName();
    $destination = Destination::create($values + [
      'id' => $id,
      'label' => 'Test destination',
      'destination' => 'opensearch',
      'destinationSettings' => [
        'url' => getenv('OPENSEARCH_HOST'),
        'username' => '',
        'password' => '',
        'prefix' => 'test_',
      ],
    ]);
    $destination->save();
    return $destination;
  }

  /**
   * A method to create a dataset using the OpenSearch destination.
   */
  protected function createTestOpenSearchDataset(array $values = []): DatasetInterface {
    return $this->createTestDataset($values + [
      'destinations' => [$this->createTestOpenSearchDestination()],
      'pipeline' => 'opensearch_test_pipeline_1',
    ]);
  }

}
